@@ -4,10 +4,10 @@ NULL
 #' SQL quoting.
 #'
 #' Pool object wrappers around DBIConnection methods that deal
-#' with SQL escaping needs. See \code{\link[DBI]{SQL}} for the
+#' with SQL escaping needs. See [DBI::SQL()] for the
 #' original documentation.
 #'
-#' @param conn,x,... See \code{\link[DBI]{SQL}}.
+#' @param conn,x,... See [DBI::SQL()].
 #'
 #' @name DBI-connection-quote
 NULL
@@ -22,6 +22,26 @@ setMethod("dbQuoteIdentifier", c("Pool", "ANY"),
   }
 )
 
+#' @export
+#' @rdname DBI-connection-quote
+setMethod("dbUnquoteIdentifier", c("Pool", "ANY"),
+  function(conn, x, ...) {
+    connection <- poolCheckout(conn)
+    on.exit(poolReturn(connection))
+    DBI::dbUnquoteIdentifier(connection, x, ...)
+  }
+)
+
+#' @export
+#' @rdname DBI-connection-quote
+setMethod("dbQuoteLiteral", c("Pool", "ANY"),
+  function(conn, x, ...) {
+    connection <- poolCheckout(conn)
+    on.exit(poolReturn(connection))
+    DBI::dbQuoteLiteral(connection, x, ...)
+  }
+)
+
 #' @export
 #' @rdname DBI-connection-quote
 setMethod("dbQuoteString", c("Pool", "ANY"),
